@@ -22,15 +22,24 @@ query_bndespar_desimbursements <- function(year = 'all') {
 
   link <- "https://www.bndes.gov.br/arquivos/central-downloads/operacoes_renda_variavel/desembolsos-renda-variavel.csv"
 
-  message('Please wait for the download to complete.')
+  # Download data
+    if (RCurl::url.exists(link == F)) { # network is down = message (not an error anymore)
+      message("No internet connection or data source broken.")
+      return(NULL)
+    } else { # network is up = proceed to download
+      message("Please wait for the download to complete.")
 
-  df <- readr::read_csv2(link, locale = readr::locale(encoding = "latin1"), show_col_types = FALSE,
-                         skip = 4) |>
-    janitor::clean_names() |>
-    dplyr::filter(ano %in% year)
+      suppressWarnings({
 
-  message("Completed data query.")
+      df <- readr::read_csv2(link, locale = readr::locale(encoding = "latin1"), show_col_types = FALSE,
+                             skip = 4) |>
+        janitor::clean_names() |>
+        dplyr::filter(ano %in% year)
 
-  return(df)
+      })
 
+      message("Completed data query.")
+
+      return(df)
+    } # /if - network up or down
 }
